# Topsis-Shreya-101953015
This is a python package for rank calculation using topsis.

## Steps for Installation
**Step 1:** Install the package using
```pip install Topsis-Shreya-101953015```

**Step 2:** Import the package
```tp =import("Topsis-Shreya-101953015"))```

**Step 3:** Run the package in command prompt in the same format as given in the following example:
```tp.topsis('101953015-data.csv',"1,1,1,1,1","+,-,+,-,+",'101953015-result.csv')```

_Result gets stored in 101953015-result.csv_

## Subject to constraints:

(1) Impacts and weights must be separated by commas.

(2) Impacts must be either +ve or -ve.

(3) Command prompt should include 4 paramters namely - input csv file, weights, impacts and name of the output csv file.

## License

© 2022 Shreya Garg

This repository is licensed under the MIT license. See LICENSE for details.